@@ -56,7 +56,7 @@
 const uint16_t MAX_VOICES = 32;			// polyphony
 const uint8_t  MAX_NOTES  = 128;
 
-const float MIN_ENV_MSECS = 2.0f;		// min 2 msec per stage
+const float MIN_ENV_MSECS = 0.5f;		// min 500 usec per stage
 const float MAX_ENV_MSECS = 5000.0f;	// max 5 sec per stage (default)
 
 const float DETUNE_SCALE  = 0.5f;
@@ -270,14 +270,11 @@ struct synthv1_env
 		p->running = true;
 		p->stage = Attack;
 		p->frames = uint32_t(*attack * *attack * max_frames);
+		if (p->frames < min_frames1) // prevent click on too fast attack
+			p->frames = min_frames1;
 		p->phase = 0.0f;
-		if (p->frames > 0) {
-			p->delta = 1.0f / float(p->frames);
-			p->value = 0.0f;
-		} else {
-			p->delta = 0.0f;
-			p->value = 1.0f;
-		}
+		p->delta = 1.0f / float(p->frames);
+		p->value = 0.0f;
 		p->c1 = 1.0f;
 		p->c0 = 0.0f;
 	}
@@ -287,8 +284,8 @@ struct synthv1_env
 		if (p->stage == Attack) {
 			p->stage = Decay;
 			p->frames = uint32_t(*decay * *decay * max_frames);
-			if (p->frames < min_frames) // prevent click on too fast decay
-				p->frames = min_frames;
+			if (p->frames < min_frames2) // prevent click on too fast decay
+				p->frames = min_frames2;
 			p->phase = 0.0f;
 			p->delta = 1.0f / float(p->frames);
 			p->c1 = *sustain - 1.0f;
@@ -320,8 +317,8 @@ struct synthv1_env
 		p->running = true;
 		p->stage = Release;
 		p->frames = uint32_t(*release * *release * max_frames);
-		if (p->frames < min_frames) // prevent click on too fast release
-			p->frames = min_frames;
+		if (p->frames < min_frames2) // prevent click on too fast release
+			p->frames = min_frames2;
 		p->phase = 0.0f;
 		p->delta = 1.0f / float(p->frames);
 		p->c1 = -(p->value);
@@ -332,7 +329,7 @@ struct synthv1_env
 	{
 		p->running = true;
 		p->stage = Release;
-		p->frames = min_frames;
+		p->frames = min_frames2;
 		p->phase = 0.0f;
 		p->delta = 1.0f / float(p->frames);
 		p->c1 = -(p->value);
@@ -344,7 +341,7 @@ struct synthv1_env
 		p->running = true;
 		if (legato) {
 			p->stage = Decay;
-			p->frames = min_frames;
+			p->frames = min_frames2;
 			p->phase = 0.0f;
 			p->delta = 1.0f / float(p->frames);
 			p->c1 = *sustain - p->value;
@@ -352,9 +349,9 @@ struct synthv1_env
 		} else {
 			p->stage = Attack;
 			p->frames = uint32_t(*attack * *attack * max_frames);
+			if (p->frames < min_frames1)
+				p->frames = min_frames1;
 			p->phase = 0.0f;
-			if (p->frames < min_frames)
-				p->frames = min_frames;
 			p->delta = 1.0f / float(p->frames);
 			p->c1 = 1.0f;
 			p->c0 = 0.0f;
@@ -368,7 +365,8 @@ struct synthv1_env
 	synthv1_port sustain;
 	synthv1_port release;
 
-	uint32_t min_frames;
+	uint32_t min_frames1;
+	uint32_t min_frames2;
 	uint32_t max_frames;
 };
 
@@ -422,9 +420,11 @@ struct synthv1_dco
 	synthv1_port shape1;
 	synthv1_port width1;
 	synthv1_port bandl1;
+	synthv1_port sync1;
 	synthv1_port shape2;
 	synthv1_port width2;
 	synthv1_port bandl2;
+	synthv1_port sync2;
 	synthv1_port balance;
 	synthv1_port detune;
 	synthv1_port phase;
@@ -1168,19 +1168,23 @@ void synthv1_impl::updateEnvTimes_1 (void)
 
 	float envtime_msecs = 10000.0f * m_dco1.envtime0;
 	if (envtime_msecs < MIN_ENV_MSECS)
-		envtime_msecs = MIN_ENV_MSECS * 2.0f;
+		envtime_msecs = MIN_ENV_MSECS * 4.0f;
 
-	const uint32_t min_frames = uint32_t(srate_ms * MIN_ENV_MSECS);
-	const uint32_t max_frames = uint32_t(srate_ms * envtime_msecs);
+	const uint32_t min_frames1 = uint32_t(srate_ms * MIN_ENV_MSECS);
+	const uint32_t min_frames2 = (min_frames1 << 2);
+	const uint32_t max_frames  = uint32_t(srate_ms * envtime_msecs);
 
-	m_dcf1.env.min_frames = min_frames;
-	m_dcf1.env.max_frames = max_frames;
+	m_dcf1.env.min_frames1 = min_frames1;
+	m_dcf1.env.min_frames2 = min_frames2;
+	m_dcf1.env.max_frames  = max_frames;
 
-	m_lfo1.env.min_frames = min_frames;
-	m_lfo1.env.max_frames = max_frames;
+	m_lfo1.env.min_frames1 = min_frames1;
+	m_lfo1.env.min_frames2 = min_frames2;
+	m_lfo1.env.max_frames  = max_frames;
 
-	m_dca1.env.min_frames = min_frames;
-	m_dca1.env.max_frames = max_frames;
+	m_dca1.env.min_frames1 = min_frames1;
+	m_dca1.env.min_frames2 = min_frames2;
+	m_dca1.env.max_frames  = max_frames;
 }
 
 
@@ -1191,19 +1195,23 @@ void synthv1_impl::updateEnvTimes_2 (void)
 
 	float envtime_msecs = 10000.0f * m_dco2.envtime0;
 	if (envtime_msecs < MIN_ENV_MSECS)
-		envtime_msecs = MIN_ENV_MSECS * 2.0f;
+		envtime_msecs = MIN_ENV_MSECS * 4.0f;
 
-	const uint32_t min_frames = uint32_t(srate_ms * MIN_ENV_MSECS);
-	const uint32_t max_frames = uint32_t(srate_ms * envtime_msecs);
+	const uint32_t min_frames1 = uint32_t(srate_ms * MIN_ENV_MSECS);
+	const uint32_t min_frames2 = (min_frames1 << 2);
+	const uint32_t max_frames  = uint32_t(srate_ms * envtime_msecs);
 
-	m_dcf2.env.min_frames = min_frames;
-	m_dcf2.env.max_frames = max_frames;
+	m_dcf2.env.min_frames1 = min_frames1;
+	m_dcf2.env.min_frames2 = min_frames2;
+	m_dcf2.env.max_frames  = max_frames;
 
-	m_lfo2.env.min_frames = min_frames;
-	m_lfo2.env.max_frames = max_frames;
+	m_lfo2.env.min_frames1 = min_frames1;
+	m_lfo2.env.min_frames2 = min_frames2;
+	m_lfo2.env.max_frames  = max_frames;
 
-	m_dca2.env.min_frames = min_frames;
-	m_dca2.env.max_frames = max_frames;
+	m_dca2.env.min_frames1 = min_frames1;
+	m_dca2.env.min_frames2 = min_frames2;
+	m_dca2.env.max_frames  = max_frames;
 }
 
 
@@ -1281,9 +1289,11 @@ synthv1_port *synthv1_impl::paramPort ( synthv1::ParamIndex index )
 	case synthv1::DCO1_SHAPE1:    pParamPort = &m_dco1.shape1;      break;
 	case synthv1::DCO1_WIDTH1:    pParamPort = &m_dco1.width1;      break;
 	case synthv1::DCO1_BANDL1:    pParamPort = &m_dco1.bandl1;      break;
+	case synthv1::DCO1_SYNC1:     pParamPort = &m_dco1.sync1;       break;
 	case synthv1::DCO1_SHAPE2:    pParamPort = &m_dco1.shape2;      break;
 	case synthv1::DCO1_WIDTH2:    pParamPort = &m_dco1.width2;      break;
 	case synthv1::DCO1_BANDL2:    pParamPort = &m_dco1.bandl2;      break;
+	case synthv1::DCO1_SYNC2:     pParamPort = &m_dco1.sync2;       break;
 	case synthv1::DCO1_BALANCE:   pParamPort = &m_dco1.balance;     break;
 	case synthv1::DCO1_DETUNE:    pParamPort = &m_dco1.detune;      break;
 	case synthv1::DCO1_PHASE:     pParamPort = &m_dco1.phase;       break;
@@ -1336,9 +1346,11 @@ synthv1_port *synthv1_impl::paramPort ( synthv1::ParamIndex index )
 	case synthv1::DCO2_SHAPE1:    pParamPort = &m_dco2.shape1;      break;
 	case synthv1::DCO2_WIDTH1:    pParamPort = &m_dco2.width1;      break;
 	case synthv1::DCO2_BANDL1:    pParamPort = &m_dco2.bandl1;      break;
+	case synthv1::DCO2_SYNC1:     pParamPort = &m_dco2.sync1;       break;
 	case synthv1::DCO2_SHAPE2:    pParamPort = &m_dco2.shape2;      break;
 	case synthv1::DCO2_WIDTH2:    pParamPort = &m_dco2.width2;      break;
 	case synthv1::DCO2_BANDL2:    pParamPort = &m_dco2.bandl2;      break;
+	case synthv1::DCO2_SYNC2:     pParamPort = &m_dco1.sync2;       break;
 	case synthv1::DCO2_BALANCE:   pParamPort = &m_dco2.balance;     break;
 	case synthv1::DCO2_DETUNE:    pParamPort = &m_dco2.detune;      break;
 	case synthv1::DCO2_PHASE:     pParamPort = &m_dco2.phase;       break;
@@ -1570,8 +1582,21 @@ void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
 						+ *m_dco1.tuning * TUNING_SCALE;
 					const float detune1
 						= *m_dco1.detune * DETUNE_SCALE;
-					pv->dco1_freq1 = synthv1_freq(note1 - detune1);
-					pv->dco1_freq2 = synthv1_freq(note1 + detune1);
+					// syncs
+					if (*m_dco1.sync1 > 0.5f) {
+						pv->dco1_freq2 = synthv1_freq(note1);
+						pv->dco1_osc2.sync(&pv->dco1_osc1);
+					} else {
+						pv->dco1_freq2 = synthv1_freq(note1 + detune1);
+						pv->dco1_osc2.sync(NULL);
+					}
+					if (*m_dco1.sync2 > 0.5f) {
+						pv->dco1_freq1 = synthv1_freq(note1);
+						pv->dco1_osc1.sync(&pv->dco1_osc2);
+					} else {
+						pv->dco1_freq1 = synthv1_freq(note1 - detune1);
+						pv->dco1_osc1.sync(NULL);
+					}
 					// phases
 					const float phase1 = *m_dco1.phase * PHASE_SCALE;
 					pv->dco1_sample1 = pv->dco1_osc1.start(  0.0f, pv->dco1_freq1);
@@ -1626,8 +1651,21 @@ void synthv1_impl::process_midi ( uint8_t *data, uint32_t size )
 						+ *m_dco2.tuning * TUNING_SCALE;
 					const float detune2
 						= *m_dco2.detune * DETUNE_SCALE;
-					pv->dco2_freq1 = synthv1_freq(note2 - detune2);
-					pv->dco2_freq2 = synthv1_freq(note2 + detune2);
+					// syncs
+					if (*m_dco2.sync1 > 0.5f) {
+						pv->dco2_freq2 = synthv1_freq(note2);
+						pv->dco2_osc2.sync(&pv->dco2_osc1);
+					} else {
+						pv->dco2_freq2 = synthv1_freq(note2 + detune2);
+						pv->dco2_osc2.sync(NULL);
+					}
+					if (*m_dco2.sync2 > 0.5f) {
+						pv->dco2_freq1 = synthv1_freq(note2);
+						pv->dco2_osc1.sync(&pv->dco2_osc2);
+					} else {
+						pv->dco2_freq1 = synthv1_freq(note2 - detune2);
+						pv->dco2_osc1.sync(NULL);
+					}
 					// phases
 					const float phase2 = *m_dco2.phase * PHASE_SCALE;
 					pv->dco2_sample1 = pv->dco2_osc1.start(  0.0f, pv->dco2_freq1);
