@@ -1,7 +1,7 @@
 // synthv1_config.cpp
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -310,13 +310,14 @@ void synthv1_config::load (void)
 	sPreset = QSettings::value("/Preset").toString();
 	sPresetDir = QSettings::value("/PresetDir").toString();
 	iKnobDialMode = QSettings::value("/KnobDialMode", 0).toInt();
+	iKnobEditMode = QSettings::value("/KnobEditMode", 0).toInt();
 	bControlsEnabled = QSettings::value("/ControlsEnabled", false).toBool();
 	bProgramsEnabled = QSettings::value("/ProgramsEnabled", false).toBool();
 	QSettings::endGroup();
 
 	QSettings::beginGroup("/Dialogs");
 	bProgramsPreview = QSettings::value("/ProgramsPreview", false).toBool();
-	bUseNativeDialogs = QSettings::value("/UseNativeDialogs", true).toBool();
+	bUseNativeDialogs = QSettings::value("/UseNativeDialogs", false).toBool();
 	// Run-time special non-persistent options.
 	bDontUseNativeDialogs = !bUseNativeDialogs;
 	QSettings::endGroup();
@@ -337,6 +338,7 @@ void synthv1_config::save (void)
 	QSettings::setValue("/Preset", sPreset);
 	QSettings::setValue("/PresetDir", sPresetDir);
 	QSettings::setValue("/KnobDialMode", iKnobDialMode);
+	QSettings::setValue("/KnobEditMode", iKnobEditMode);
 	QSettings::setValue("/ControlsEnabled", bControlsEnabled);
 	QSettings::setValue("/ProgramsEnabled", bProgramsEnabled);
 	QSettings::endGroup();
@@ -355,3 +357,4 @@ void synthv1_config::save (void)
 
 
 // end of synthv1_config.cpp
+
