@@ -1,7 +1,7 @@
 // synthv1_config.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,7 +28,7 @@
 
 #define SYNTHV1_SUBTITLE    "an old-school polyphonic synthesizer."
 #define SYNTHV1_WEBSITE     "http://synthv1.sourceforge.net"
-#define SYNTHV1_COPYRIGHT   "Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved."
+#define SYNTHV1_COPYRIGHT   "Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved."
 
 #define SYNTHV1_DOMAIN      "rncbc.org"
 
@@ -59,8 +59,9 @@ public:
 	QString sPreset;
 	QString sPresetDir;
 
-	// Dial knob behavior mode.
+	// Knob behavior modes.
 	int iKnobDialMode;
+	int iKnobEditMode;
 
 	// Special persistent options.
 	bool bControlsEnabled;
@@ -121,3 +122,4 @@ private:
 #endif	// __synthv1_config_h
 
 // end of synthv1_config.h
+
