@@ -43,17 +43,10 @@ public:
 	~synthv1_controls();
 
 	// operational mode flags.
-	enum Mode { Enabled = 1, Optional = 2 };
-
 	void enabled(bool on)
-		{ if (on) m_mode |= Enabled; else m_mode &= ~Enabled; }
+		{ m_enabled = on; }
 	bool enabled() const
-		{ return m_mode & Enabled; }
-
-	void optional(bool on)
-		{ if (on) m_mode |= Optional; else m_mode &= ~Optional; }
-	bool optional() const
-		{ return m_mode & Optional; }
+		{ return m_enabled; }
 
 	// controller types,
 	enum Type { None = 0, CC = 0x100, RPN = 0x200, NRPN = 0x300, CC14 = 0x400 };
@@ -104,6 +97,7 @@ public:
 
 	// controller events.
 	struct Event
+
 	{
 		Key key;
 		unsigned short value;
@@ -200,7 +194,7 @@ private:
 	Impl *m_pImpl;
 
 	// operational mode flags.
-	unsigned int m_mode;
+	bool m_enabled;
 
 	// controller schedulers.
 	SchedIn  m_sched_in;
