@@ -582,7 +582,7 @@ void synthv1_jack::sessionEvent ( void *pvSessionArg )
 	args << QString("\"${SESSION_DIR}%1\"").arg(sSessionFile);
 
 	synthv1_param::savePreset(this,
-		QFileInfo(sSessionDir, sSessionFile).absoluteFilePath());
+		QFileInfo(sSessionDir, sSessionFile).absoluteFilePath(), true);
 
 	const QByteArray aCmdLine = args.join(" ").toUtf8();
 	pJackSessionEvent->command_line = ::strdup(aCmdLine.constData());
@@ -822,7 +822,7 @@ void synthv1_jack_application::saveSession (void)
 //	const QString& client_id = m_pNsmClient->client_id();
 	const QFileInfo fi(path_name, display_name + '.' + SYNTHV1_TITLE);
 
-	synthv1_param::savePreset(m_pSynth, fi.absoluteFilePath());
+	synthv1_param::savePreset(m_pSynth, fi.absoluteFilePath(), true);
 
 	m_pNsmClient->save_reply();
 	m_pNsmClient->dirty(false);
