@@ -145,9 +145,6 @@ synthv1_lv2::synthv1_lv2 (
 	m_outs = new float * [nchannels];
 	for (uint16_t k = 0; k < nchannels; ++k)
 		m_ins[k] = m_outs[k] = NULL;
-
-	synthv1::programs()->optional(true);
-	synthv1::controls()->optional(true);
 }
 
 
