@@ -1,7 +1,7 @@
 // synthv1_param.h
 //
 /****************************************************************************
-   Copyright (C) 2012-2016, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2012-2017, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,10 +38,11 @@ class QDomDocument;
 namespace synthv1_param
 {
 	// Preset serialization methods.
-	void loadPreset(synthv1 *pSynth,
-		const QString& sFilename);
-	void savePreset(synthv1 *pSynth,
+	bool loadPreset(synthv1 *pSynth,
 		const QString& sFilename);
+	bool savePreset(synthv1 *pSynth,
+		const QString& sFilename,
+		bool bSymLink = false);
 
 	// Default parameter name/value helpers.
 	const char *paramName(synthv1::ParamIndex index);
