@@ -21,6 +21,8 @@
 
 #include "synthv1_ui.h"
 
+#include "synthv1_param.h"
+
 
 //-------------------------------------------------------------------------
 // synthv1_ui - decl.
@@ -44,6 +46,17 @@ bool synthv1_ui::isPlugin (void) const
 }
 
 
+bool synthv1_ui::loadPreset ( const QString& sFilename )
+{
+	return synthv1_param::loadPreset(m_pSynth, sFilename);
+}
+
+bool synthv1_ui::savePreset ( const QString& sFilename )
+{
+	return synthv1_param::savePreset(m_pSynth, sFilename);
+}
+
+
 void synthv1_ui::setParamValue ( synthv1::ParamIndex index, float fValue )
 {
 	m_pSynth->setParamValue(index, fValue);
