@@ -63,6 +63,10 @@ public:
 	uint32_t size() const
 		{ return m_nsize; }
 
+	// phase-zero (for slave reset)
+	float phase0() const
+		{ return m_phase0; }
+
 	// init.
 	void reset(Shape shape, float width, bool bandl = false);
 	// init.sync.
@@ -79,11 +83,21 @@ public:
 	// phasor.
 	struct Phase
 	{
+		Phase() { reset(); }
+
 		float    phase;
 		float    ftab;
 		uint16_t itab;
 
-		void reset() { phase = ftab = 0.0f; itab =  0; }
+		Phase   *slave;
+		float    slave_phase0;
+
+		void reset()
+		{
+			phase = ftab = slave_phase0 = 0.0f;
+			itab  = 0;
+			slave = 0;
+		}
 	};
 
 	// begin.
@@ -108,8 +122,11 @@ public:
 		const float p0 = float(m_nsize);
 
 		phase.phase += p0 * freq / m_srate;
-		if (phase.phase >= p0)
+		if (phase.phase >= p0) {
 			phase.phase -= p0;
+			if (phase.slave)
+				phase.slave->phase = phase.slave_phase0;
+		}
 
 		if (phase.itab < m_ntabs) {
 			const float x0 = interp(i, phase.itab, alpha);
@@ -285,10 +302,21 @@ public:
 	void update(float freq)
 		{ m_wave->update(m_phase, freq); }
 
+	// hard-sync slave.
+	void sync(synthv1_oscillator *slave)
+	{
+		if (slave && slave->m_wave) {
+			m_phase.slave = &(slave->m_phase);
+			m_phase.slave_phase0 = (slave->m_wave)->phase0();
+		} else {
+			m_phase.slave = 0;
+			m_phase.slave_phase0 = 0.0f;
+		}
+	}
+
 private:
 
-	synthv1_wave *m_wave;
-
+	synthv1_wave       *m_wave;
 	synthv1_wave::Phase m_phase;
 };
 
