@@ -129,6 +129,11 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	m_ui.Dcf1SlopeKnob->insertItems(0, slopes);
 	m_ui.Dcf2SlopeKnob->insertItems(0, slopes);
 
+	m_ui.Dco1Sync1Knob->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
+	m_ui.Dco1Sync2Knob->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
+	m_ui.Dco2Sync1Knob->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
+	m_ui.Dco2Sync2Knob->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
+
 	// Dynamic states.
 	QStringList states;
 	states << tr("Off");
@@ -292,9 +297,11 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DCO1_SHAPE1,  m_ui.Dco1Shape1Knob);
 	setParamKnob(synthv1::DCO1_WIDTH1,  m_ui.Dco1Width1Knob);
 	setParamKnob(synthv1::DCO1_BANDL1,  m_ui.Dco1Bandl1Knob);
+	setParamKnob(synthv1::DCO1_SYNC1,   m_ui.Dco1Sync1Knob);
 	setParamKnob(synthv1::DCO1_SHAPE2,  m_ui.Dco1Shape2Knob);
 	setParamKnob(synthv1::DCO1_WIDTH2,  m_ui.Dco1Width2Knob);
 	setParamKnob(synthv1::DCO1_BANDL2,  m_ui.Dco1Bandl2Knob);
+	setParamKnob(synthv1::DCO1_SYNC2,   m_ui.Dco1Sync2Knob);
 	setParamKnob(synthv1::DCO1_BALANCE, m_ui.Dco1BalanceKnob);
 	setParamKnob(synthv1::DCO1_DETUNE,  m_ui.Dco1DetuneKnob);
 	setParamKnob(synthv1::DCO1_PHASE,   m_ui.Dco1PhaseKnob);
@@ -504,9 +511,11 @@ synthv1widget::synthv1widget ( QWidget *pParent, Qt::WindowFlags wflags )
 	setParamKnob(synthv1::DCO2_SHAPE1,  m_ui.Dco2Shape1Knob);
 	setParamKnob(synthv1::DCO2_WIDTH1,  m_ui.Dco2Width1Knob);
 	setParamKnob(synthv1::DCO2_BANDL1,  m_ui.Dco2Bandl1Knob);
+	setParamKnob(synthv1::DCO2_SYNC1,   m_ui.Dco2Sync1Knob);
 	setParamKnob(synthv1::DCO2_SHAPE2,  m_ui.Dco2Shape2Knob);
 	setParamKnob(synthv1::DCO2_WIDTH2,  m_ui.Dco2Width2Knob);
 	setParamKnob(synthv1::DCO2_BANDL2,  m_ui.Dco2Bandl2Knob);
+	setParamKnob(synthv1::DCO2_SYNC2,   m_ui.Dco2Sync2Knob);
 	setParamKnob(synthv1::DCO2_BALANCE, m_ui.Dco2BalanceKnob);
 	setParamKnob(synthv1::DCO2_DETUNE,  m_ui.Dco2DetuneKnob);
 	setParamKnob(synthv1::DCO2_PHASE,   m_ui.Dco2PhaseKnob);
@@ -953,6 +962,18 @@ void synthv1widget::updateParamEx ( synthv1::ParamIndex index, float fValue )
 		m_ui.Dco1Bandl2Knob->setEnabled(
 			synthv1_wave::Shape(int(fValue)) != synthv1_wave::Noise);
 		break;
+	case synthv1::DCO1_SYNC1:
+		if (fValue > 0.5f) {
+			m_ui.Dco1Sync2Knob->setValue(0.0f);
+			updateParam(synthv1::DCO1_SYNC2, 0.0f);
+		}
+		break;
+	case synthv1::DCO1_SYNC2:
+		if (fValue > 0.5f) {
+			m_ui.Dco1Sync1Knob->setValue(0.0f);
+			updateParam(synthv1::DCO1_SYNC1, 0.0f);
+		}
+		break;
 	case synthv1::DCO2_SHAPE1:
 		m_ui.Dco2Bandl1Knob->setEnabled(
 			synthv1_wave::Shape(int(fValue)) != synthv1_wave::Noise);
@@ -961,6 +982,18 @@ void synthv1widget::updateParamEx ( synthv1::ParamIndex index, float fValue )
 		m_ui.Dco2Bandl2Knob->setEnabled(
 			synthv1_wave::Shape(int(fValue)) != synthv1_wave::Noise);
 		break;
+	case synthv1::DCO2_SYNC1:
+		if (fValue > 0.5f) {
+			m_ui.Dco2Sync2Knob->setValue(0.0f);
+			updateParam(synthv1::DCO2_SYNC1, 0.0f);
+		}
+		break;
+	case synthv1::DCO2_SYNC2:
+		if (fValue > 0.5f) {
+			m_ui.Dco2Sync1Knob->setValue(0.0f);
+			updateParam(synthv1::DCO1_SYNC1, 0.0f);
+		}
+		break;
 	case synthv1::DCF1_SLOPE:
 		m_ui.Dcf1TypeKnob->setEnabled(int(fValue) != 3); // !Formant
 		break;
